# frozen_string_literal: true

require 'import'
require 'graphql'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/helpers/graphql/raise_error'

require 'user_management/errors'

module UserManagement
  module Actions
    module CRN

      # TODO: Move to the fabric and template generator
      class CoerceInput
        include ::Platform::Helpers::GraphQL::RaiseError

        # TODO: Find a better pattern where this can be listed
        OWNED_SERVICES = ["user", "user-group"]

        def call(str, ctx)
          crn = ::Platform::CRN.from_s str

          if crn.customer > 0 && ctx[:request].current_customer != crn.customer
            raise_error ::UserManagement::ErrorCodes::NOT_FOUND,
                        "Invalid tenant: user record not found"
          end

          unless OWNED_SERVICES.include?(crn.service)
            raise_error ::UserManagement::ErrorCodes::INVALID_SERVICE,
                        "Queried for invalid service"
          end

          crn
        rescue ::Platform::InvalidCRNError
          raise_error ::UserManagement::ErrorCodes::INVALID_CRN,
                      "Invalid CRN format with query"
        end
      end

    end
  end
end
