# frozen_string_literal: true

require 'import'
require 'graphql'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/helpers/graphql/raise_error'

require 'user_management/errors'

module UserManagement
  module Actions
    module CRN

      # TODO: Move to the fabric and template generator
      class CoerceResult
        include ::Platform::Helpers::GraphQL::RaiseError
        include Import["alert"]

        def call(crn, ctx)
          ctx_request = ctx[:request]
          # Checks for a x-tenant leak, rollbars and raises an internal error
          if crn.customer > 0  && ctx[:request].current_customer != crn.customer
            alert.error "X-tenant leak detected while processing request",
                        request: ctx_request

            raise_error ::UserManagement::ErrorCodes::INTERNAL_ERROR,
                        "X-tenant leak detected when processing request"
          end

          crn.to_s
        end
      end

    end
  end
end
