# frozen_string_literal: true
require 'cht-lib-fabric/contexts/request'
require 'user_management/models/service_integration_user'
require 'user_management/utils/account_utils'

module UserManagement
  module Actions
    class FindIntegrationUser
      include Import['logger']
      include UserManagement::Account::Utils
      def call(service_integration, current_customer)
        logger.info("Adding service account #{service_integration}")
        app = if service_integration&.keys[0].eql?("id")
          logger.info("Adding #{service_integration}")
          service_integration
        else
          app_key = service_integration&.keys[0]
          logger.info("Adding #{service_integration[app_key]}")
          service_integration[app_key]
        end
        # Fill out the approval piece with query on user
        # We'll use the creator of the user group because user
        # doesn't track that info, and the same user would have
        # created both due to how approval works.
        sia_user = 
           Stores::ArModels::User.where(customer_id: current_customer, oauth_app_id: app['oauthAppId'], name: app['name'], is_deleted: false, service_account: true).first
        # Debug
        logger.info("SIA User Found #{sia_user}")
        # Should only be member of one group, we validate
        # this someplace else         
        sia_user_group = sia_user&.user_groups
        unless sia_user_group.nil? || sia_user_group.count == 0
          sia_user_group = sia_user_group.to_a[0]
        end

        user_id = sia_user_group&.created_by&.id ? sia_user_group&.created_by&.id : 0
        user_customer_id = sia_user_group&.customer&.id ? sia_user_group&.customer&.id : 0
        approved_by_crn = ::Platform::CRNs::User.new(user: user_id, customer: user_customer_id) unless sia_user.nil?
        # This will be NULL for cross tenant users (i.e CHT Admin that approves an account)
        approved_by_user = Stores::ArModels::User.where(customer_id: user_customer_id, id: user_id).first unless approved_by_crn.nil?
        # Get a tenant ID from an approved account, if not approved, use the user customer ID of the caller that
        # the account would be approved in.
        tenant_id = user_customer_id == 0 ? current_customer : user_customer_id
        # Generate an email address that is unique
        email_address = sia_user.nil? ? generate_email_address(app['name'], tenant_id) : sia_user.email

        logger.info ("APP #{app.to_json}")

        ::UserManagement::Models::ServiceIntegrationUser.new(
            id: app['id'],
            name: app['name'],
            email: email_address,
            description: app['description'],
            approved: !sia_user.nil?,
            approved_on: sia_user&.created_at,
            approved_by: approved_by_crn,
            approved_by_user: approved_by_user,
            role_document_id: app['roleDocument']
        )
      end
    end
  end
end
