# frozen_string_literal: true

require 'import'

module UserManagement
  module Actions
    class RemoveUserFromUserGroups
      include Import[:logger, :alert]

      def remove_user_from_user_groups(customer_id, user_id)
        customer = ::UserManagement::Stores::ArModels::Customer.find(customer_id)
        user = UserManagement::Stores::ArModels::User.where(customer_id: customer_id, id: user_id).first

        if !user.nil?
          #switching to customer data shard to get user-group records
          customer.using_data_shard do

            user_group_ids = user.user_groups.ids
            existing_groups = Stores::ArModels::UserGroup.where(
                customer_id: customer_id,
                id: user_group_ids)

            existing_groups.each do |existing_group|
              ActiveRecord::Base.transaction do
                number_of_user_before_update = existing_group.users.size
                logger.info { "Number of users before update : #{number_of_user_before_update} for user-group : #{existing_group.id}"}
                existing_group.users = existing_group.users.reject do |u|
                  u.id == user.id
                end
                number_of_user_after_update = existing_group.users.size
                if(number_of_user_after_update != number_of_user_before_update)
                  existing_group.touch
                end
                logger.info { "Number of users after update : #{number_of_user_after_update} for user-group : #{existing_group.id}" }
                existing_group.save!
              end
            end
          end
        else
          error_msg = "Deleted user #{user_id} not found. Check if it was a hard delete"
          logger.error(error_msg)
        end
      end
    end
  end
end