# frozen_string_literal: true

require 'cht-lib-fabric/graphql/client'
require 'cht-lib-fabric/helpers/graphql/raise_error'
require 'cht-lib-fabric/error_codes'
require 'import'

module UserManagement
  module Clients
    class PrivilegeEscalationChecker < ::Platform::GraphQL::Client
      include ::Platform::Helpers::GraphQL::RaiseError
      include Import['logger']
      schema(File.expand_path('../../../config/schemas/privilege_escalation_checker.json', __dir__))
      queries(File.expand_path('./privilege_escalation_checker.graphql', __dir__))

      # @param subject [String] The type of resource we want to access
      # @param action [String] The action we are requesting escalation check for
      # @return true if privilege escalation else false
      # @raise on any network or GraphQL error
      def privilegeEscalated(subject:, action:, context: {})
        raise ArgumentError, "must be nonempty on non-null: action" if action.nil? || action.empty?

        logger.info("Querying privilege escalation for #{action} on user_group_id: #{subject}")
        begin
          data = query(
            Queries::PrivilegeEscalationForUserGroup,
            context,
            input: {
              escalationInputs: {
                subject: {crn: subject},
                action: action
              }
            }
          )
        rescue => ex
          ctx_request_id = context[:request].request_id
          logger.error("Exception occured: #{ex.class}: #{ex.message}")
          raise_error(::Platform::ErrorCodes::NOT_FOUND, "Record not found!",
                      uuid: ctx_request_id)
        end

        escalated = data.is_privilege_escalation_for_user_group.escalation
        logger.debug("Result of privilege escalation for  #{action} on user_group_id #{subject} : #{escalated}")
        escalated
      end
    end
  end
end
