# frozen_string_literal: true

require 'cht-lib-fabric/graphql/client'
require 'import'
require 'user_management/traceable'

module UserManagement
  module Clients
    class RoleManagement < ::Platform::GraphQL::Client
      extend Traceable
      # The query file and json file are generated by a Rake task
      schema(File.expand_path('../../../config/schemas/cht-svc-role-management.json', __dir__))
      queries(File.expand_path('./role_management.graphql', __dir__))

      def get_role_documents(user_group_crns, context = {})
        params = {
          "filter": {
            "rules": [{
              "field": "userGroupId",
              "type": "EQ",
              "values": user_group_crns
            }]
          }
        }
        data = query_with_retry(Queries::UserGroupRoleBindings, context,::UserManagement::Retry::RATE_RETRY_LIMIT, params)
        data
      end

      # Creates a role binding the corresponding user group, in the current organizations, to the corresponding organization
      def create_role_binding(user_group_id, organization_id, role_document_id, context = {})
        data = query(
          Queries::UpdateUserGroupRoleBindings,
          context,
          input: {
            creates: [
              {
                userGroup: {
                  id: "#{user_group_id}"
                },
                roleDocument: {
                  id: "#{role_document_id}"
                },
                organizations: [
                  { 
                    id: "#{organization_id}" 
                  }
                ]
              }
            ]
          }
        )
        data
      end

      trace_method :get_role_documents
    end
  end
end
