# frozen_string_literal: true

require 'graphql'
require 'active_support/dependencies/autoload'

require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/helpers/graphql'

module UserManagement
  module GraphQL
    module Types
      extend ActiveSupport::Autoload

      autoload :Query
      autoload :Mutation

      autoload :ActiveRecordWrapperFieldExtension
      autoload :FilterableExtension
      autoload :Mutations
      autoload :SortableExtension
      autoload :MembershipSource
      autoload :User
      autoload :UserGroup
      autoload :UserGroupIdentityAttributeRule
      autoload :UserGroupIdentityAttributeRuleInput
      autoload :FederatedUser
      autoload :ServiceIntegrationUser

      # TODO: not sure this will be useful
      class CRN < ::GraphQL::Schema::Scalar
        extend ::Platform::Helpers::GraphQL::RaiseError

        def self.coerce_input(input_value, context)
          crn = ::Platform::CRN.from_s(input_value)

          if crn.customer > 0 && context[:request].current_customer != crn.customer
            raise ::GraphQL::ExecutionError, "Tenant in CRN NOT owned by requested user"
          end

          crn
        rescue ::Platform::InvalidCRNError
          raise ::GraphQL::CoercionError, "#{input_value.inspect} is an invalid CRN value"
        end
      end
    end
  end
end
