# frozen_string_literal: true

require 'graphql'
require 'user_management/stores/ar_models'

module UserManagement
  module GraphQL
    module Types
      module Mutations
        module RequestValidator
          def self.included(includer)
            # Ensure the class inherits from GraphQL::Schema::Resolver
            # so it has a `context` attribute
            klass = includer
            loop do
              break if klass.nil?
              return super if klass == ::GraphQL::Schema::Resolver
              klass = klass.superclass
            end
            raise NoMethodError, "Expected to have method :context defined"
          end

          def validate_request_has_organization!
            if context[:request].current_organization.nil? || context[:request].current_organization <= 0
              raise ::GraphQL::ExecutionError, "An organization is required"
            end
          end

          def validate_request_has_user!
            if context[:request].current_user.nil?
              raise ::GraphQL::ExecutionError, "An user ID is required to execute this request"
            end
          end
        end
      end
    end
  end
end
