# frozen_string_literal: true

module UserManagement
  module GraphQL
    module Types
      module Resolvers
        class DefaultOrganizationResolver

          def initialize(value, query_ctx)
            # Store these for later when the value is resolved.
            @value = value
            @query_context = query_ctx
          end

          def default_organization_id
            user = UserManagement::Stores::ArModels::User.where(id: @value[:user_by_id].details, customer_id: @value[:user_by_id].customer).first
            raise ::GraphQL::ExecutionError, "User not found when looking up default organization" if user.nil?
            preferred_organization = get_preferred_organization(@query_context, @value)
            # If they indicated a preference but for whatever reason it wasn't found throw
            # an error back to caller
            if has_org_preference?(@value)
              raise ::GraphQL::ExecutionError, "Preferred organization not found when looking up default organization" if preferred_organization.nil?
            end
            org = user.default_organization(@query_context, preferred_organization)
            return org.id if org.present?
            raise ::GraphQL::ExecutionError, "No Default organization identified for user [#{user.id}]"
          rescue => ex
            raise ::GraphQL::ExecutionError, "An Error Occurred: #{ex.message}"
          end

          #
          # Returns the preferred organization specified by
          # the caller. We'll do this here to avoid having
          # to check whether the org exists AND that the
          # user experessed a preference.
          #
          def get_preferred_organization(context, value)

            return unless has_org_preference?(value)

            customer_id = context[:request].current_customer

            UserManagement::Stores::ArModels::Organization.where(customer_id: customer_id, id: value[:preferred_organization].details).first

          end

          #
          # Returns a boolean indicating whether the user indicated a 
          # preferred organization
          #
          def has_org_preference?(value)
            return false if value.nil?
            return false if value[:preferred_organization].nil?
            return true
          end
        end
      end
    end
  end
end
