# frozen_string_literal: true

require 'graphql'
require 'cht-lib-fabric/crns'

module UserManagement
  module GraphQL
    module Types
      DESCRIPTION = 'An integration user in the the Aria Cost Platform.'
      
      class ServiceIntegrationUser < ::Platform::GraphQL::Types::BaseObject
        implements ::GraphQL::Relay::Node.interface
        field :id, ID, "A string representing a service integration user ID", null: false
        field :name, String, "A string representing the name of the service integration user ID", null: false
        field :description, String, "A string representing the description of the service integration user", null: true
        field :email, String, "A string representing the email service integration user ID", null: false
        field :approved, Boolean, "A boolean indicating whether a service integration has been approved", null: false
        field :approved_by, ID, "A string representing the ID of the user that approved the service integration account", null: true
        field :approved_by_user, User, "A User object representing the service integration account", null: true
        field :approved_on, ::GraphQL::Types::ISO8601DateTime, "The date and time the service integration account was approved", null: true
        field :role_document_id, ID, "A string representing a service integration role document ID", null: false
      end
    end
  end
end

