# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/crns'
require 'user_management/actions/remove_user_from_user_groups'

module UserManagement
  module Helpers
    class UserGroupHelper
      include Import[:logger, :alert]
      def cleanup_user_group(params)
            logger.debug { "processing user change message. params: #{params.to_h}" }
            crn = ::Platform::CRN.from_s(params['crn'])
            action = params['action'].downcase
            customer_id = crn.customer
            user_id = crn.details.to_i
            params_to_h = params.to_h 
    
            case action
                when 'delete'
                logger.info { "user #{crn} has been deleted. Cleaning up user-group user association records" }
                UserManagement::Actions::RemoveUserFromUserGroups.new.remove_user_from_user_groups(customer_id, user_id)
                end
            rescue => ex
                alert.exception(
                    ex,
                    params: params_to_h,
                    customer_id: (defined?(crn) && !crn.nil?) ? crn.customer : nil
                )
            raise
      end
    end
  end  
end