# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/dry_types'

module UserManagement
  class KafkaMessage
    include Import[
      :settings,
      'kafka.producers'
    ]

    TOPIC = "com.cloudhealthtech.svc.user_management.usergroups.change"

    ADD    = "ADD"
    DELETE = "DELETE"
    CHANGE = "CHANGE"

    def push(user_group, context, type = CHANGE)
      customer_id = context[:request].current_customer
      organization_id = context[:request].current_organization
      user_id = context[:request].current_user
      user_group_name = user_group.name
      user_group_id = user_group.id
      payload = {
        id: ::Platform::CRN.from_s("crn:#{customer_id}:user-group/#{user_group_id}").to_s,
        customer_id: customer_id,
        user_id: ::Platform::CRN.from_s("crn:#{customer_id}:user/#{user_id}").to_s,
        organization_id: ::Platform::CRN.from_s("crn:#{customer_id}:organization/#{organization_id}").to_s,
        name: user_group_name,
        type: type,
      }

      topic = if settings.kafka_topic_prefix.blank?
              then TOPIC
              else "#{settings.kafka_topic_prefix}.#{TOPIC}"
              end

      producers.with do |producer|
        puts "PRODUCER CLASS [#{producer.class.name}]"
        producer.produce(payload.to_json,
                         key: user_group_id,
                         topic: topic)
        begin
          producer.deliver_messages
        rescue ::Kafka::DeliveryFailed
          producer.clear_buffer
          raise
        end
      end
    end
  end
end
