require 'user_management/utils/model_replication'

module UserManagement
  module Stores
    module ArModels
      class Customer < ActiveRecord::Base
        include UserManagement::Utils::ModelReplication

        has_many :shard_assignments
        has_many :organizations
        has_many :users
        has_many :user_groups

        scope :assigned_to_current_shard, -> {
          joins(:shard_assignments)
          .where(
            shard_assignments: {
              data_store_id: 2,
              shard_id: ::Multidb.current_shard_id
            }
          )
        }

        # This is a special version of `active` that must match cht_models
        scope :active, -> { where(is_deleted: false, is_active: true) }

        def default_organization
          # TODO: New Logic for this
          orgs = organizations.where(default_organization: true).limit(2)
          raise "More than 1 default organization for customer: #{id}" if orgs.length > 1
          orgs.first
        end

        def data_shard(store = DataStore::MAIN)
          @data_shard ||= ShardAssignment.lookup_by_name(store, id)
        end

        def using_data_shard(&block)
          Multidb.use(data_shard) { ActiveRecord::Base.cache(&block) }
        end

        def self.data_shard(id)
          ShardAssignment.lookup_by_name(DataStore::MAIN, id)
        end

        def self.using_data_shard_for(id, &block)
          Multidb.use(data_shard(id)) { ActiveRecord::Base.cache(&block) }
        end
      end
    end
  end
end
