module UserManagement
  module Stores
    module ArModels
      class Organization < ActiveRecord::Base
        validates :name, presence: true
        validates_uniqueness_of :sso_uid, scope: :customer_id, allow_blank: true, allow_nil: true

        belongs_to :customer
        belongs_to :organization

        belongs_to :parent_organization, class_name: 'UserManagement::Stores::ArModels::Organization'


        has_many :organization_users
        has_and_belongs_to_many :users, join_table: :organization_users
        has_many :child_organizations, class_name: 'UserManagement::Stores::ArModels::Organization', foreign_key: :parent_organization_id
        has_and_belongs_to_many :users

        before_save :set_flex_org
        # we should never have an organization with a parent organization
        # id and also flex_org == false
        def set_flex_org
          self.flex_org = true unless parent_organization_id.nil?
        end
        
        # Gets a list of ids of parent organizations all the way up to the root
        # Orders them as parent being last
        def parent_organizations
          return [] if parent_organization_id.nil?
          return @parent_organizations if @parent_organizations
          @parent_organizations ||= []
          @parent_organizations << parent_organization_id
          @parent_organizations.concat(parent_organization.parent_organizations)
          @parent_organizations
        end

      end
    end
  end
end
