require 'user_management/utils/model_replication'
module UserManagement
  module Stores
    module ArModels
      class ShardAssignment < ::ActiveRecord::Base
        include ::UserManagement::Utils::ModelReplication

        belongs_to :customer
        belongs_to :data_store

        # Simplified implementation that does not look at redis
        def self.lookup_by_name(ds_name, customer_id)
          ::Multidb.use(:master) do
            assignment = select(:shard_id).joins(:data_store).find_by(data_stores: { name: ds_name }, customer_id: customer_id)
            id_to_name(ds_name, assignment.shard_id) if assignment
          end
        end

        def self.id_to_name(ds_name, shard_id)
          case ds_name
          when 'ird'
            "ird#{shard_id}"
          when 'main'
            "db#{shard_id}"
          when 'es'
            shard_id.to_s
          when 'es_cloudtrail'
            shard_id.to_s
          when 'es_awsconfig'
            shard_id.to_s
          when 'azure_ird'
            "ird_azure#{shard_id}"
          when 'es_metrics'
            shard_id.to_s
          when 'es_metrics_index'
            shard_id.to_s
          else
            "Unknown DataStore name: #{ds_name}"
          end
        end
      end
    end
  end
end
