# frozen_string_literal: true

require 'active_record'

module UserManagement
  module Stores
    module ArModels
      class UserGroup < ::ActiveRecord::Base
        belongs_to              :customer
        belongs_to              :organization

        belongs_to :created_by, class_name: 'User', foreign_key: :created_by_id
        belongs_to :updated_by, class_name: 'User', foreign_key: :updated_by_id

        has_many :identity_attribute_rules

        has_many :user_groups_users

        has_many :users, through: :user_groups_users do
          def <<(user)
            proxy_association.owner.save! unless proxy_association.owner.persisted?
            proxy_association.owner.find_or_create_user(user).save!
            proxy_association.owner.reload
          end
        end

        def users=(users_to_assign)
          new_users = users_to_assign - users
          old_users = users - users_to_assign
          new_users.each do |user|
            find_or_create_user(user).save!
          end
          old_users.each do |user|
            find_or_create_user(user).delete
          end
          reload
          users_to_assign
        end

        def find_or_create_user(user)
          Stores::ArModels::UserGroupsUser.where(customer_id: customer_id,
                                               user_id: user.id,
                                               user_group_id: id).first_or_initialize
        end

        def crnify
          "crn:#{customer_id}:user-group/#{id}"
        end

        def update_all_attributes!(updated_by_user_id:, name:, description: nil, identity_attribute_rules:, customer_id:)
          transaction do
            self.updated_by_id = updated_by_user_id
            self.name = name
            self.description = description
            self.customer_id = customer_id

            # TODO: some day, make this churn less.
            # Today, we don't really care if these rows are created and destroyed regularly.
            self.identity_attribute_rules.each(&:destroy)
            self.identity_attribute_rules = identity_attribute_rules.map do |rule_input|
              IdentityAttributeRule.new(
                customer_id: customer_id,
                rule_key: rule_input[:key],
                identity_attribute_rule_values: rule_input[:values].map do |rule_value_input|
                  IdentityAttributeRuleValue.new(rule_value: rule_value_input, customer_id: customer_id)
                end
              )
            end

            self.save!
          end
        end
      end
    end
  end
end
