# frozen_string_literal: true

module UserManagement
  module Utils
    class CallerValidator

      SERVICE_ACCOUNT = 'service-account'
      CLOUDPERCEPT_ACCOUNT = 'service-account/cloudpercept'
      USER_ACCOUNT = ':user/'

      def initialize(request, token_validator)
        @request = request
        @token = request.env['HTTP_AUTHORIZATION'].split(' ')[1]
        @token_validator = token_validator
      end

      def user_account?
        account.include?(USER_ACCOUNT)
      end

      def service_account?
        account.include?(SERVICE_ACCOUNT)
      end

      def cloudpercept_service_account?
        account.include?(CLOUDPERCEPT_ACCOUNT)
      end

      def account
        validated = @token_validator.call(@token)
        return '' if validated.failure?
        values = validated.value![:jwt]
        values['sub']
      end

    end
  end
end
