# frozen_string_literal: true

module UserManagement
  module Utils
    class CaseInsensitiveHash < Hash

      def self.from_hash(hash)
        output = new
        return output if hash.blank?
        hash.each do |k, v|
          output[k] = v
        end
        output
      end

      def self.[](values)
        new_values = values.map do |val|
          [_insensitive(val[0]), val[1]]
        end
        super(new_values)
      end

      def self._insensitive(key)
        key.respond_to?(:downcase) ? key.downcase : key
      end

      def key?(key)
        super _insensitive(key)
      end

      def [](key)
        super _insensitive(key)
      end

      def []=(key, value)
        super _insensitive(key), value
      end

      def delete(key)
        super _insensitive(key)
      end

      # Keeping it DRY.
      protected

      def _insensitive(key)
        key.respond_to?(:downcase) ? key.downcase : key
      end
    end
  end
end
