# frozen_string_literal: true
require 'user_management/kafka_message'

module UserManagement
  module Utils
    module EventPublish
      # 
      # Publish a kafka event for a user group
      #
      # @param - object      - The object representing the user group
      # @param - context     - The request context for the event
      # @param - type        - The type of change, defaults to 'CHANGE'
      def publish(object, context, type = ::UserManagement::KafkaMessage::CHANGE)
        kafka_message.push(object, context, type) unless object.nil?
      rescue => ex
        logger.error "Unable to publish #{type} event for #{object.class} #{ex.message}"
        alert.exception(
          ex,
          customer_id: context[:request].current_customer,
          user_id: context[:request].current_user,
          organization_id: context[:request].current_organization,
          action: type
        )
      end
    end
  end
end
