# frozen_string_literal: true
require 'user_management/stores/ar_models'

module UserManagement
  module Utils
    class MembershipUpdater

      attr_accessor :customer, :user, :raw_info, :case_sensitive

      def initialize(customer, user, raw_info, case_sensitive = false)
        @customer = customer
        @user = user
        @case_sensitive = case_sensitive
        @raw_info = case_sensitive ? raw_info : ::UserManagement::Utils::CaseInsensitiveHash.from_hash(raw_info)
      end

      def update_memberships
        customers_groups = customer.user_groups.includes(:identity_attribute_rules, identity_attribute_rules: [ :identity_attribute_rule_values])
        groups_to_assign = customers_groups.select do |group|
          # Should we remain in this group?
          rules_with_keys = group.identity_attribute_rules.select { |rule| check_acceptance(rule.rule_key, raw_info.keys) }
          rules_with_keys.any? do |rule|
            idp_info = raw_info[rule.rule_key]
            rule.identity_attribute_rule_values.any?{|value| check_acceptance(value.rule_value, idp_info) }
          end
        end
        # Update user_groups_user placing the user
        # in each of the new groups they should be in
        user.user_groups = groups_to_assign
        groups_to_assign.map(&:id)
      end

      def check_acceptance(value, options)
        options = options.is_a?(Array) ? options : [options]
        if case_sensitive
          value.in?(options)
        else
          value.to_s.downcase.in?(options.map{|o| o.to_s.downcase})
        end
      end

    end
  end
end
